@@ -52,8 +52,9 @@ struct _ArvGcBooleanClass {
 
 GType 		arv_gc_boolean_get_type 	(void);
 ArvGcNode * 	arv_gc_boolean_new 		(void);
-gboolean 	arv_gc_boolean_get_value 	(ArvGcBoolean *gc_boolean);
-void 		arv_gc_boolean_set_value 	(ArvGcBoolean *gc_boolean, gboolean v_boolean);
+
+gboolean 	arv_gc_boolean_get_value 	(ArvGcBoolean *gc_boolean, GError **error);
+void 		arv_gc_boolean_set_value 	(ArvGcBoolean *gc_boolean, gboolean v_boolean, GError **error);
 
 G_END_DECLS
 
